@@ -28,7 +28,7 @@ def console_entry_point():
     main_parser.add_argument('--sec-locale', metavar='LOCALE', help="""The system language is English, second locale set others stuff like: date format, numeric dot etc.
     Default: 'en_US'""")
     main_parser.add_argument('--swap-size', metavar='SIZE', help="""It is used as a second RAM, it is recommended to have one
-    Default: '4192' (It should be provided in bytes)""", default='4192')
+    Default: 'size of your ram' (It should be provided in MB)""")
     main_parser.set_defaults(execute=lambda args: execute_alis_fn('alis_defaults', args.device, args.root_pass, args.sec_locale, args.swap_size))
     sub_parser = main_parser.add_subparsers()
 
@@ -68,7 +68,7 @@ There is some groups of packages:
     parser.add_argument('--timezone', metavar='TIMEZONE', help="""It is used to set time by location.
     Default: 'it will be current location'""")
     parser.add_argument('--swap', metavar='SWAP_SIZE', help="""It is used as a second RAM, it is recommended to have one
-    Default: '4192' (It should be provided in bytes)""", default='4192')
+    Default: 'size of your ram' (It should be provided in MB)""")
     parser.set_defaults(execute=lambda args: execute_alis_fn('alis_config_minimum', args.root_pass, args.arch_name, args.sec_locale, args.swap, args.timezone))
     parser = sub_parser.add_parser('admin-user', description="Set an sudo user", formatter_class=argparse.RawTextHelpFormatter)
     parser.add_argument('username', help="""Admin user name
