@@ -415,6 +415,8 @@ numlock-state=true
 show-desktop=['<Super>d']
 switch-applications=@as []
 switch-applications-backward=@as []
+switch-to-workspace-left=@as []
+switch-to-workspace-right=@as []
 switch-windows=['<Alt>Tab']
 switch-windows-backward=['<Shift><Alt>Tab']
 
